==> kpl-3.0.tar.bz2: kpl-3.0/kpl/editdlg.h <==
/***************************************************************************
                          editdlg.h  -  description
                             -------------------
    begin                : Tue Jul 24 2001
    copyright            : (C) 2002 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef EDITDLG_H
#define EDITDLG_H

#include <kapp.h>
#include <kdialogbase.h>

class QTextEdit;
class QMultiLineEdit;

/**
  * Edit dialog class. Simple text editor based on QTextEdit.
  * @author Werner Stille
  */
class EditDlg : public KDialogBase
{
  Q_OBJECT
public:
  /**
    * Constructor.
    * @param parent parent widget.
    * @param s initial text.
    * @param ts tab stop width.
    */
#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
  EditDlg(QWidget* parent, QString* s, int ts = 0);
#else
  EditDlg(QWidget* parent, QString* s);
#endif
  /** Destructor */
  ~EditDlg();

protected:
  QString* s;
#if (KDE_VERSION_MAJOR > 2) || (KDE_VERSION_MINOR > 8)
  QTextEdit* edit;
#else
  QMultiLineEdit* edit;
#endif

protected slots:
  /** Applies settings and leaves the dialog. */
  virtual void slotOk();
  /** Applies settings without leaving the dialog. */
  virtual void slotApply();
};

#endif

==> kpl-3.1.tar.bz2: kpl-3.1/kpl/editdlg.h <==
/***************************************************************************
                          editdlg.h  -  description
                             -------------------
    begin                : Tue Jul 24 2001
    copyright            : (C) 2003 by Werner Stille
    email                : stille@uni-freiburg.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef EDITDLG_H
#define EDITDLG_H

#include <kapp.h>
#include <kdialogbase.h>

class QTextEdit;
class QMultiLineEdit;

/**
  * Edit dialog class. Simple text editor based on QTextEdit.
  * @author Werner Stille
  */
class EditDlg : public KDialogBase
{
  Q_OBJECT
public:
  /**
    * Constructor.
    * @param parent parent widget.
    * @param s initial text.
    * @param ts tab stop width.
    */
#if KDE_VERSION_MAJOR > 2
  EditDlg(QWidget* parent, QString* s, int ts = 0);
#else
  EditDlg(QWidget* parent, QString* s);
#endif
  /** Destructor */
  ~EditDlg();

protected:
  QString* s;
#if KDE_VERSION_MAJOR > 2
  QTextEdit* edit;
#else
  QMultiLineEdit* edit;
#endif

protected slots:
  /** Applies settings and leaves the dialog. */
  virtual void slotOk();
  /** Applies settings without leaving the dialog. */
  virtual void slotApply();
};

#endif
